
	--Sample Program by Prem Kumar Chittajallu <prem@bhelrnd.co.in>
	
	--intended for Lua command application demonstration
	--To compute the lift force experienced by a plate due to
	-- a dc U core electro-magnet.
	--Problem Type ; Magnetostatic - 2D(planar)

	--Lua - Pre-processor steps for : DCmagnet

	probdef(0,"millimeters","planar","1e-008")
	
	--Adding nodes defining the half C-core
	addnode(0,60)
	addnode(-50,60)
	addnode(-50,0)
	addnode(-70,0)
	addnode(-70,60)
	addnode(-50,80)
	addnode(0,80)
		
	--Joining nodes to define half C-core
	addsegment(0,60,-50,60)
	addsegment(-50,60,-50,0)
	addsegment(-50,0,-70,0)
	addsegment(-70,0,-70,60)
	addarc(-50,80,-70,60,90,10)
	addsegment(-50,80,0,80)
	
	--Adding nodes defining left half of keeper
	addnode(0,-20)
	addnode(-90,-20)
	addnode(-90,-30)
	addnode(0,-30)

	--Joining nodes to define left half of keeper
	addsegment(0,-20,-90,-20)
	addsegment(-90,-20,-90,-30)
	addsegment(-90,-30,0,-30)

	--Adding nodes to define Boundary(Left half)
	addnode(0,200)
	addnode(-200,200)
	addnode(-200,-100)
	addnode(0,-100)

	--Joining nodes to define Boundary(Left half)
	addsegment(0,200,-200,200)
	addsegment(-200,200,-200,-100)
	addsegment(-200,-100,0,-100)

	--Adding nodes to define Bottom coil(Half)
	addnode(0,58)
	addnode(-35,58)
	addnode(-35,38)
	addnode(0,38)
	
	--Joining nodes to form Bottom coil(Half)
	addsegment(0,58,-35,58)
	addsegment(-35,58,-35,38)
	addsegment(-35,38,0,38)

	--mirroring to get the top half coil
	selectsegment(-25,58)
	selectsegment(-35,48)
	selectsegment(-25,38)
	mirror(-10,70,10,70,1)
	clearselected()
	
	--Selecting segments for mirroring about Y-axis.
	selectsegment(-25,38)
	selectsegment(-35,48)
	selectsegment(-25,58)
	selectsegment(-25,60)
	selectsegment(-50,30)
	selectsegment(-60,0)
	selectsegment(-70,30)
	selectsegment(-25,80)
	selectsegment(-25,82)
	selectsegment(-35,92)
	selectsegment(-25,102)
	selectsegment(-45,-20)
	selectsegment(-90,-25)
	selectsegment(-45,-30)
	selectsegment(-100,200)
	selectsegment(-200,0)
	selectsegment(-100,-100)
	mirror(0,0,0,20,1)
	clearselected()
	addarc(70,60,50,80,90,10)
	--Geometry, including Boundary completes here.
	
	--Defining Boundary Condition
	addboundprop("outer",0,0,0,0,0,0,0,0,0)
	
	--Defining Excitations
	addcircprop("plus",2500,0,0,0,0)
	addcircprop("minus",-2500,0,0,0,0)

	--Assigning Boundary Condition
	selectsegment(-100,200)
	selectsegment(100,200)
	selectsegment(-200,0)
	selectsegment(-100,-100)
	selectsegment(100,-100)
	selectsegment(200,0)
	setsegmentprop("outer",1,1,0,0)
	clearselected()

	--Defining material
	addmaterial("iron",5000,5000,0,0,0,0,0,0,1,0)
	addmaterial("air",1,1,0,0,0,0,0,0,1,0)
	addmaterial("copper",1,1,0,0,0,0,0,0,1,0)
	
	--Assigning Material Props
	addblocklabel(0,150)
	selectlabel(0,150)
	setblockprop("air",0,10,0,0,0)
	clearselected()

	addblocklabel(0,-25)
	selectlabel(0,-25)
	setblockprop("iron",0,3,0,0,4)
	clearselected()

	addblocklabel(0,70)
	selectlabel(0,70)
	setblockprop("iron",0,4,0,0,0)
	clearselected()

	--Grouping segments forming keeper
	--For simulating movement later
	selectsegment(-45,-20)
	selectsegment(45,-20)
	selectsegment(-90,-25)
	selectsegment(90,-25)
	selectsegment(-45,-30)
	selectsegment(45,-30)
	setsegmentprop(0,1,1,0,4)
	clearselected()
	
	--Assigning excitations
	addblocklabel(0,48)
	selectlabel(0,48)
	setblockprop("copper",0,7.5,"plus",0,0)
	clearselected()

	addblocklabel(0,92)
	selectlabel(0,92)
	setblockprop("copper",0,7.5,"minus",0,0)
	clearselected()

	zoomnatural()
	messagebox("Animation begins now !!")
	
	savefemmfile("temp.fem")	
	seteditmode("group")
	
	for n =1,4 do
	createmesh()
	analyse(1)
	
	runpost("DCmagnet_post.lua")
	purgemesh()
	
	selectgroup(4)
	movetranslate(0,4.5,4)
	end
	messagebox("Ex(c)iting code !!")

	exitpre()

	

	

	



